bowl
===
[![PyPI version](https://badge.fury.io/py/bowl.svg)](http://badge.fury.io/py/bowl) [![Build Status](https://travis-ci.org/cglewis/bowl.png?branch=master)](https://travis-ci.org/cglewis/bowl) [![downloads](https://pypip.in/d/bowl/badge.png)](https://pypi.python.org/pypi/bowl) [![Coverage Status](https://coveralls.io/repos/cglewis/bowl/badge.png?branch=master)](https://coveralls.io/r/cglewis/bowl?branch=master)
